package com.leromro.core.service;

import java.util.List;
import com.baomidou.mybatisplus.extension.service.IService;
import com.leromro.core.domain.PlatformFinance;

/**
 * 平台资金流水Service接口
 * 
 * @author ruoyi
 * @date 2025-04-11
 */
public interface IPlatformFinanceService extends IService<PlatformFinance>
{
    /**
     * 查询平台资金流水
     * 
     * @param platformFinanceId 平台资金流水主键
     * @return 平台资金流水
     */
    public PlatformFinance selectPlatformFinanceByPlatformFinanceId(Long platformFinanceId);

    /**
     * 查询平台资金流水列表
     * 
     * @param platformFinance 平台资金流水
     * @return 平台资金流水集合
     */
    public List<PlatformFinance> selectPlatformFinanceList(PlatformFinance platformFinance);

    /**
     * 新增平台资金流水
     * 
     * @param platformFinance 平台资金流水
     * @return 结果
     */
    public Boolean insertPlatformFinance(PlatformFinance platformFinance);

    /**
     * 修改平台资金流水
     * 
     * @param platformFinance 平台资金流水
     * @return 结果
     */
    public Boolean updatePlatformFinance(PlatformFinance platformFinance);

    /**
     * 批量删除平台资金流水
     * 
     * @param platformFinanceIds 需要删除的平台资金流水主键集合
     * @return 结果
     */
    public int deletePlatformFinanceByPlatformFinanceIds(Long[] platformFinanceIds);

    /**
     * 删除平台资金流水信息
     * 
     * @param platformFinanceId 平台资金流水主键
     * @return 结果
     */
    public int deletePlatformFinanceByPlatformFinanceId(Long platformFinanceId);
}
